@@ -3,7 +3,7 @@ package Carton;
 use strict;
 use warnings;
 use 5.008_001;
-use version; our $VERSION = "v0.9_9";
+use version; our $VERSION = "v0.9.10";
 
 use Cwd;
 use Config qw(%Config);
@@ -87,7 +87,6 @@ sub download_from_cpanfile {
     local $self->{path} = File::Temp::tempdir(CLEANUP => 1); # ignore installed
 
     $self->run_cpanm(
-        "-v",
         "--mirror", $mirror,
         "--mirror", "http://backpan.perl.org/", # fallback
         "--mirror-index", $self->{mirror_file},
